GroupSetRequestParam class abstract

Implemented types
Mixed-in types

Constructors

GroupSetRequestParam({required GroupSetRequestArgs args})
const
GroupSetRequestParam.build({required ServerRpcVersion? version, required GroupSetRequestArgs args})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
honorSessionLimits → bool?
true if session upload limits are honored
no setteroverride
name → String
Bandwidth group name
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speedLimitDown → num?
max global download speed (KBps)
no setteroverride
speedLimitDownEnabled → bool?
true to enable group's global download speed limit
no setteroverride
speedLimitUp → num?
max global upload speed (KBps)
no setteroverride
speedLimitUpEnabled → bool?
true to enable group's global upload speed limit
no setteroverride

Methods

check() → String?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRpcJson() → JsonMap
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited