QueueMoveRequestParam class abstract

Implemented types
Implementers

Constructors

QueueMoveRequestParam({required TorrentIds<TorrentId> ids})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids → TorrentIds<TorrentId>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

check() → String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRpcJson() → JsonMap
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited