SessionSetRequestArgs class

Mixed-in types

Constructors

SessionSetRequestArgs({num? altSpeedDown, bool? altSpeedEnabled, num? altSpeedTimeBegin, num? altSpeedTimeDay, bool? altSpeedTimeEnabled, num? altSpeedTimeEnd, num? altSpeedUp, bool? blocklistEnabled, String? blocklistUrl, num? cacheSizeMb, String? defaultTrackers, bool? dhtEnabled, String? downloadDir, num? downloadDirFreeSpace, bool? downloadQueueEnabled, num? downloadQueueSize, String? encryption, bool? idleSeedingLimitEnabled, num? idleSeedingLimit, bool? incompleteDirEnabled, String? incompleteDir, bool? lpdEnabled, num? peerLimitGlobal, num? peerLimitPerTorrent, bool? peerPortRandomOnStart, num? peerPort, bool? pexEnabled, bool? portForwardingEnabled, bool? queueStalledEnabled, num? queueStalledMinutes, bool? renamePartialFiles, bool? scriptTorrentAddedEnabled, String? scriptTorrentAddedFilename, bool? scriptTorrentDoneEnabled, String? scriptTorrentDoneFilename, bool? scriptTorrentDoneSeedingEnabled, String? scriptTorrentDoneSeedingFilename, bool? seedQueueEnabled, num? seedQueueSize, num? seedRatioLimit, bool? seedRatioLimited, bool? speedLimitDownEnabled, num? speedLimitDown, bool? speedLimitUpEnabled, num? speedLimitUp, bool? startAddedTorrents, bool? trashOriginalTorrentFiles, bool? utpEnabled})
const

Properties

altSpeedDown → num?
Max global download speed (KBps)
final
altSpeedEnabled → bool?
Indicates whether alternative speeds are enabled
final
altSpeedTimeBegin → num?
Time to begin alternative speeds (units: minutes after midnight)
final
altSpeedTimeDay → num?
Day(s) to turn on alternative speeds (look at tr_sched_day)
final
altSpeedTimeEnabled → bool?
Indicates whether alternative speeds time is enabled
final
altSpeedTimeEnd → num?
Time to end alternative speeds (units: same)
final
altSpeedUp → num?
Max global upload speed (KBps)
final
blocklistEnabled → bool?
Indicates whether the blocklist is enabled
final
blocklistUrl → String?
Location of the blocklist to use for blocklist-update
final
cacheSizeMb → num?
Maximum size of the disk cache (MB)
final
defaultTrackers → String?
Announce URLs, one per line, and a blank line between tiers
final
dhtEnabled → bool?
Indicates whether DHT is enabled in public torrents
final
downloadDir → String?
Default path to download torrents
final
downloadDirFreeSpace → num?
DEPRECATED: Use freeSpace method instead.
final
downloadQueueEnabled → bool?
Indicates if limiting how many torrents can be downloaded at once is enabled
final
downloadQueueSize → num?
Max number of torrents to download at once (see downloadQueueEnabled)
final
encryption → String?
Specifies the encryption method (required, preferred, tolerated)
final
hashCode → int
The hash code for this object.
no setterinherited
idleSeedingLimit → num?
Torrents we're seeding will be stopped if they're idle for this long
final
idleSeedingLimitEnabled → bool?
Indicates if the seeding inactivity limit is honored by default
final
incompleteDir → String?
Path for incomplete torrents, when enabled
final
incompleteDirEnabled → bool?
Indicates whether incomplete directory is enabled
final
lpdEnabled → bool?
Indicates whether Local Peer Discovery in public torrents is enabled
final
peerLimitGlobal → num?
Maximum global number of peers
final
peerLimitPerTorrent → num?
Maximum global number of peers per torrent
final
peerPort → num?
Port number
final
peerPortRandomOnStart → bool?
Indicates whether to pick a random peer port on launch
final
pexEnabled → bool?
Indicates whether Peer Exchange (PEX) in public torrents is enabled
final
portForwardingEnabled → bool?
Indicates whether UPnP or NAT-PMP is enabled to forward peer ports
final
queueStalledEnabled → bool?
Indicates whether idle torrents are considered as stalled
final
queueStalledMinutes → num?
Torrents that are idle for N minutes aren't counted toward seed-queue-size or download-queue-size
final
renamePartialFiles → bool?
Indicates whether to append .part to incomplete files
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptTorrentAddedEnabled → bool?
Indicates whether to call the added script
final
scriptTorrentAddedFilename → String?
Filename of the script to run when a torrent is added
final
scriptTorrentDoneEnabled → bool?
Indicates whether to call the done script
final
scriptTorrentDoneFilename → String?
Filename of the script to run when a torrent is done
final
scriptTorrentDoneSeedingEnabled → bool?
Indicates whether to call the seeding-done script
final
scriptTorrentDoneSeedingFilename → String?
Filename of the script to run when seeding is done
final
seedQueueEnabled → bool?
Indicates if limiting how many torrents can be uploaded at once is enabled
final
seedQueueSize → num?
Max number of torrents to upload at once (see seedQueueEnabled)
final
seedRatioLimit → num?
The default seed ratio for torrents to use
final
seedRatioLimited → bool?
Indicates if seedRatioLimit is honored by default
final
speedLimitDown → num?
Max global download speed (KBps)
final
speedLimitDownEnabled → bool?
Indicates whether download speed limit is enabled
final
speedLimitUp → num?
Max global upload speed (KBps)
final
speedLimitUpEnabled → bool?
Indicates whether upload speed limit is enabled
final
startAddedTorrents → bool?
Indicates whether added torrents will be started right away
final
trashOriginalTorrentFiles → bool?
Indicates whether the .torrent file of added torrents will be deleted
final
utpEnabled → bool?
Indicates whether UDP Transport Protocol (UTP) is enabled
final

Methods

copyWith({num? altSpeedDown, bool? altSpeedEnabled, num? altSpeedTimeBegin, num? altSpeedTimeDay, bool? altSpeedTimeEnabled, num? altSpeedTimeEnd, num? altSpeedUp, bool? blocklistEnabled, String? blocklistUrl, num? cacheSizeMb, String? defaultTrackers, bool? dhtEnabled, String? downloadDir, num? downloadDirFreeSpace, bool? downloadQueueEnabled, num? downloadQueueSize, String? encryption, bool? idleSeedingLimitEnabled, num? idleSeedingLimit, bool? incompleteDirEnabled, String? incompleteDir, bool? lpdEnabled, num? peerLimitGlobal, num? peerLimitPerTorrent, bool? peerPortRandomOnStart, num? peerPort, bool? pexEnabled, bool? portForwardingEnabled, bool? queueStalledEnabled, num? queueStalledMinutes, bool? renamePartialFiles, bool? scriptTorrentAddedEnabled, String? scriptTorrentAddedFilename, bool? scriptTorrentDoneEnabled, String? scriptTorrentDoneFilename, bool? scriptTorrentDoneSeedingEnabled, String? scriptTorrentDoneSeedingFilename, bool? seedQueueEnabled, num? seedQueueSize, num? seedRatioLimit, bool? seedRatioLimited, bool? speedLimitDownEnabled, num? speedLimitDown, bool? speedLimitUpEnabled, num? speedLimitUp, bool? startAddedTorrents, bool? trashOriginalTorrentFiles, bool? utpEnabled}) → SessionSetRequestArgs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited