TorrentSetRequestParam class abstract

Implemented types
Mixed-in types

Constructors

TorrentSetRequestParam({required TorrentSetRequestArgs args})
const
TorrentSetRequestParam.build({ServerRpcVersion? version, required TorrentSetRequestArgs args})
factory

Properties

allowedFields → Set<TorrentSetArgument>
no setter
bandwidthPriority → num?
Gets the bandwidth priority of the torrent.
no setteroverride
deprecatedFields → Set<TorrentSetArgument>
no setter
downloadLimit → num?
Gets the maximum download speed of the torrent (in KBps).
no setteroverride
downloadLimited → bool?
Indicates whether the download limit is honored.
no setteroverride
filesUnwanted → FileIndices?
Gets the indices of unwanted files.
no setteroverride
filesWanted → FileIndices?
Gets the indices of wanted files.
no setteroverride
group → String?
Gets the name of the torrent's bandwidth group. (new in rpc-version 17)
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
honorsSessionLimits → bool?
Indicates whether session upload limits are honored.
no setteroverride
ids → TorrentIds<TorrentId>
Gets the IDs of torrents.
no setteroverride
labels → List<String>?
Gets the array of string labels. (new in rpc-version 16)
no setteroverride
location → String?
Gets the location of the torrent's content.
no setteroverride
peerLimit → num?
Gets the maximum number of peers.
no setteroverride
priorityHigh → FileIndices?
Gets the indices of high-priority files.
no setteroverride
priorityLow → FileIndices?
Gets the indices of low-priority files.
no setteroverride
priorityNormal → FileIndices?
Gets the indices of normal-priority files.
no setteroverride
queuePosition → num?
Gets the position of the torrent in its queue.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seedIdleLimit → num?
Gets the torrent-level number of minutes of seeding inactivity.
no setteroverride
seedIdleMode → IdleLimitMode?
Gets the seeding inactivity mode.
no setteroverride
seedRatioLimit → num?
Gets the torrent-level seeding ratio limit.
no setteroverride
seedRatioMode → RatioLimitMode?
Gets the seeding ratio mode.
no setteroverride
sequentialDownload → bool?
Indicates whether to download torrent pieces sequentially. (new in rpc-version 19)
no setteroverride
trackerAdd → List<String>?
Deprecated in rpc-version>=17, use trackerList instead. Gets the list of tracker URLs to add.
no setteroverride
trackerList → TrackerListIter?
Gets the list of tracker URLs. (new in rpc-version 17)
no setteroverride
trackerRemove → List<TrackerId>?
Deprecated in rpc-version>=17, use trackerList instead. Gets the list of trackers to remove.
no setteroverride
trackerReplace → List<TrackerReplace>?
Deprecated in rpc-version>=17, use trackerList instead. Gets the list of trackers to replace.
no setteroverride
uploadLimit → num?
Gets the maximum upload speed of the torrent (in KBps).
no setteroverride
uploadLimited → bool?
Indicates whether the upload limit is honored.
no setteroverride

Methods

check() → String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRpcJson() → JsonMap
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited